#!/bin/bash

### VARIABLES TO SET ###
#Path to mitochondrial ref
RefPath="/home/devel/irenel/scratch/refs/Pan_troglodytes_troglodytes-MT.fa"
#Path to the organism nuclear genome
NuclearRef="/home/devel/irenel/scratch/refs/panTro4.fa"
#Name of mitochondria in ref
chrM="chrM"
#Working directory
cd /home/devel/irenel/scratch/mtArchitect


### PATHS TO TOOLS ###
bwa="/apps/BWA/0.7.12/bin/bwa"
samtools="/apps/SAMTOOLS/1.3/AVX0/GCC/bin/samtools"
bam2fastq="/apps/BAM2FASTQ/1.1.0/bin/bam2fastq"
tabix="/apps/TABIX/0.2.5/bin/tabix"
bcftools="/apps/BCFTOOLS/1.3.1/bin/bcftools"
picardtools="/apps/PICARD/1.110"
hapsembler="/apps/HAPSEMBLER/2.21/bin"
blast="/apps/BLAST+/2.2.30/bin"
bgzip="/apps/TABIX/0.2.5/bin/bgzip"
vcf="/apps/VCFTOOLS/0.1.14/bin"
Rscript="/apps/R/3.2.0/bin/Rscript"

mtArchitect="/home/devel/irenel/scratch/mtArchitect/scripts"

### FIXED VARIABLES ###
fastq1=$1
fastq2=$2
Sample=$3
#Number of iterations in iterative mapping step
iteration=10
system=$(uname -a | awk '{print $1}')

export PERL5LIB=$PERL5LIB:${vcf/bin/perl}





### PIPELINE STEPS ###
# 1. LAX MAPPING
# 2. ITERATIVE MAPPING
# 3. MAPPING TO MODIFIED REF
# 4. NUCLEAR MAPPING
# 5. ASSEMBLY


### 1.LAX MAPPING ###
mkdir Mappings
${bwa} index $RefPath
#Lax mapping, sort, index
${bwa} mem -A 4 -t 4 $RefPath $fastq1 $fastq2 | ${samtools} view -Sbh - | ${samtools} sort - -o Mappings/${Sample}.FirstMapping.bam -T Mappings/${Sample}.FirstMapping.tmp 
${samtools} index Mappings/${Sample}.FirstMapping.bam
#Remove unmapped reads (4) and secondary alignments (2048)
${samtools} view -b -F 2052 Mappings/${Sample}.FirstMapping.bam > Mappings/${Sample}.FirstMapping_mapped.bam
#Filter all unmapped reads to filter unmapped mates of mapped reads from there
${samtools} view -b -f 4 Mappings/${Sample}.FirstMapping.bam > Mappings/${Sample}.FirstMapping_Allunmapped.bam
#Extract unpaired reads in mapped bam (Because samtools flags informing about the pair state cannot be trusted)
${samtools} view Mappings/${Sample}.FirstMapping_mapped.bam | awk '{print $1}' | sort | uniq -c | awk '{if ($1==1) print $2}' > Mappings/${Sample}.UnpairedMappedReads
#Extract unmapped pairs
headerFM=$(${samtools} view -h Mappings/${Sample}.FirstMapping_mapped.bam | head -2)
echo -e "${headerFM}" > Mappings/${Sample}.UnmappedMates
${samtools} view Mappings/${Sample}.FirstMapping_Allunmapped.bam | grep -wf Mappings/${Sample}.UnpairedMappedReads >> Mappings/${Sample}.UnmappedMates
${samtools} view -Shb Mappings/${Sample}.UnmappedMates > Mappings/${Sample}.UnmappedMates.bam
#Merge mapped reads and their pairs, sort, index
${samtools} merge Mappings/${Sample}.FirstMappingMerged.bam Mappings/${Sample}.FirstMapping_mapped.bam Mappings/${Sample}.UnmappedMates.bam
${samtools} sort Mappings/${Sample}.FirstMappingMerged.bam -o Mappings/${Sample}.FirstMappingMergedSort.bam -T Mappings/${Sample}.FirstMappingMergedSort.tmp
${samtools} index Mappings/${Sample}.FirstMappingMergedSort.bam
#Bam2fastq
${bam2fastq} -o Mappings/${Sample}.FirstMapping#.fastq Mappings/${Sample}.FirstMappingMergedSort.bam
#Interleave fastq and filter it
${mtArchitect}/interleave-fastq.py Mappings/${Sample}.FirstMapping_1.fastq Mappings/${Sample}.FirstMapping_2.fastq | perl ${mtArchitect}/trimming_fastq_dinn.pl 32 > Mappings/${Sample}.FirstMappingQual.fastq


###2.ITERATIVE MAPPING ###
mkdir IterativeMapping/
mkdir IterativeMapping/${Sample}
mkdir IterativeMapping/${Sample}/Iterations
mkdir IterativeMapping/${Sample}/FINAL

ItPath="IterativeMapping/${Sample}/Iterations"
FINALPath="IterativeMapping/${Sample}/FINAL"

#Iteration 1
i=1
#Strict mapping of fastq obtained in first step
${bwa} mem -A 2 -O 7 -L 10 -p $RefPath Mappings/${Sample}.FirstMappingQual.fastq | ${samtools} view -f 2 -Su - | ${samtools} sort - -o $ItPath/iteration${i}_${Sample}.bam -T $ItPath/${Sample}.iteration${i}.tmp
${samtools} index $ItPath/iteration${i}_${Sample}.bam
#SNP calling, create consensus an align to standard ref 
${samtools} mpileup -L 10000 -d 10000 -C50 -gf $RefPath $ItPath/iteration${i}_${Sample}.bam | ${bcftools} call --ploidy 1 -c - | ${mtArchitect}/Parse_Homozygous.pl | ${bgzip} > $ItPath/iteration${i}_${Sample}.vcf.gz
${tabix} -p vcf $ItPath/iteration${i}_${Sample}.vcf.gz
cat $RefPath | ${vcf}/vcf-consensus $ItPath/iteration${i}_${Sample}.vcf.gz > $ItPath/iteration${i}_${Sample}_MT.fasta
${bwa} mem $RefPath $ItPath/iteration${i}_${Sample}_MT.fasta | ${samtools} view -Sb - | ${samtools} sort - -o $ItPath/iteration${i}_${Sample}_MT.bam -T $ItPath/${Sample}.iteration${i}.tmp
${samtools} index $ItPath/iteration${i}_${Sample}_MT.bam
${bwa} index $ItPath/iteration${i}_${Sample}_MT.fasta
java -Xmx2g -jar ${picardtools}/CreateSequenceDictionary.jar  R=$ItPath/iteration${i}_${Sample}_MT.fasta O=$ItPath/iteration${i}_${Sample}_MT.dict



#Iterations 2 to $iteration-4
for i in $(seq 2 1 $iteration)
do
        k=$((i-1))
        ${bwa} mem -A 2 -O 7 -L 10 -p $ItPath/iteration${k}_${Sample}_MT.fasta Mappings/${Sample}.FirstMappingQual.fastq | ${samtools} view -f 2 -Su - | ${samtools} sort - -o $ItPath/iteration${i}_${Sample}.bam -T $ItPath/${Sample}.iteration${i}.tmp
        ${samtools} index $ItPath/iteration${i}_${Sample}.bam
        ${samtools} mpileup -L 10000 -d 10000 -C50 -gf $ItPath/iteration${k}_${Sample}_MT.fasta $ItPath/iteration${i}_${Sample}.bam | ${bcftools} call --ploidy 1 -c - | ${mtArchitect}/Parse_Homozygous.pl | ${bgzip} > $ItPath/iteration${i}_${Sample}.vcf.gz
        ${tabix} -p vcf $ItPath/iteration${i}_${Sample}.vcf.gz
        cat $ItPath/iteration${k}_${Sample}_MT.fasta | ${vcf}/vcf-consensus $ItPath/iteration${i}_${Sample}.vcf.gz > $ItPath/iteration${i}_${Sample}_MT.fasta
        ${bwa} mem $RefPath $ItPath/iteration${i}_${Sample}_MT.fasta | ${samtools} view -Sb - | ${samtools} sort - -o $ItPath/iteration${i}_${Sample}_MT.bam -T $ItPath/${Sample}.iteration${i}.tmp
        ${samtools} index $ItPath/iteration${i}_${Sample}_MT.bam
        ${bwa} index $ItPath/iteration${i}_${Sample}_MT.fasta
        java -Xmx2g -jar ${picardtools}/CreateSequenceDictionary.jar  R=$ItPath/iteration${i}_${Sample}_MT.fasta O=$ItPath/iteration${i}_${Sample}_MT.dict
done


# Three last with stricter bwa parameters
${bwa} mem -p $ItPath/iteration${iteration}_${Sample}_MT.fasta Mappings/${Sample}.FirstMappingQual.fastq | ${samtools} view -f 2 -Su - | ${samtools} sort - -o $FINALPath/FINAL_${Sample}_1.bam -T $FINALPath/${Sample}.iterationFinal.tmp
${samtools} index $FINALPath/FINAL_${Sample}_1.bam
${samtools} mpileup -L 10000 -d 10000 -C50 -gf $ItPath/iteration${iteration}_${Sample}_MT.fasta $FINALPath/FINAL_${Sample}_1.bam | ${bcftools} call --ploidy 1 -c - | ${mtArchitect}/Parse_Homozygous.pl | ${bgzip} > $FINALPath/FINAL_${Sample}_1.vcf.gz
${tabix} -p vcf $FINALPath/FINAL_${Sample}_1.vcf.gz
cat $ItPath/iteration${iteration}_${Sample}_MT.fasta | ${vcf}/vcf-consensus $FINALPath/FINAL_${Sample}_1.vcf.gz > $FINALPath/FINAL_${Sample}_1_MT.fasta
${bwa} index $FINALPath/FINAL_${Sample}_1_MT.fasta

${bwa} mem -B 6 -p $FINALPath/FINAL_${Sample}_1_MT.fasta Mappings/${Sample}.FirstMappingQual.fastq | ${samtools} view -f 2 -Su - | ${samtools} sort - -o $FINALPath/FINAL_${Sample}_2.bam -T $FINALPath/${Sample}.iterationFinal2.tmp
${samtools} index $FINALPath/FINAL_${Sample}_2.bam
${samtools} mpileup -L 10000 -d 10000 -C50 -gf $FINALPath/FINAL_${Sample}_1_MT.fasta $FINALPath/FINAL_${Sample}_2.bam | ${bcftools} call --ploidy 1 -c - | ${mtArchitect}/Parse_Homozygous.pl | ${bgzip} > $FINALPath/FINAL_${Sample}_2.vcf.gz
${tabix} -p vcf $FINALPath/FINAL_${Sample}_2.vcf.gz
cat $FINALPath/FINAL_${Sample}_1_MT.fasta | ${vcf}/vcf-consensus $FINALPath/FINAL_${Sample}_2.vcf.gz > $FINALPath/FINAL_${Sample}_2_MT.fasta
${bwa} index $FINALPath/FINAL_${Sample}_2_MT.fasta

${bwa} mem -B 8 -p $FINALPath/FINAL_${Sample}_2_MT.fasta Mappings/${Sample}.FirstMappingQual.fastq | ${samtools} view -f 2 -Su - | ${samtools} sort - -o $FINALPath/FINAL_${Sample}_3.bam -T $FINALPath/${Sample}.iterationFinal3.tmp
${samtools} index $FINALPath/FINAL_${Sample}_3.bam
${samtools} mpileup -L 10000 -d 10000 -C50 -gf $FINALPath/FINAL_${Sample}_2_MT.fasta $FINALPath/FINAL_${Sample}_3.bam | ${bcftools} call --ploidy 1 -c - | ${mtArchitect}/Parse_Homozygous.pl | ${bgzip} > $FINALPath/FINAL_${Sample}_3.vcf.gz
${tabix} -p vcf $FINALPath/FINAL_${Sample}_3.vcf.gz
cat $FINALPath/FINAL_${Sample}_2_MT.fasta | ${vcf}/vcf-consensus $FINALPath/FINAL_${Sample}_3.vcf.gz > $FINALPath/FINAL_${Sample}_MT.fasta
#Create modified reference
${bwa} index $FINALPath/FINAL_${Sample}_MT.fasta

${bwa} mem -B 8 -p $FINALPath/FINAL_${Sample}_MT.fasta Mappings/${Sample}.FirstMappingQual.fastq | ${samtools} view -f 2 -Su - | ${samtools} sort - -o $FINALPath/FINAL_${Sample}.bam -T $FINALPath/${Sample}.final.tmp
${samtools} index $FINALPath/FINAL_${Sample}.bam



# SHIFT MODIFIED REF

ModRef="$FINALPath/FINAL_${Sample}_MT.fasta"
header=$(cat $ModRef | head -1)
echo "$header" > $FINALPath/FINAL_${Sample}_MT.shift.fasta
for length in $(cat $ModRef | tail -n+2 | tr -d '\n'| wc -m);do
    end=$(cat $ModRef | tail -n+2 | tr -d '\n'| cut -c 1-8000)
    beg=$(cat $ModRef | tail -n+2 | tr -d '\n'| cut -c 8001-$length)
    if [ "$system" == "Darwin" ]; then
        echo $beg$end | sed -e 's/.\{51\}/&\'$'\n/g' >> $FINALPath/FINAL_${Sample}_MT.shift.fasta
    else
        echo $beg$end | sed -e 's/.\{51\}/&\n/g' >> $FINALPath/FINAL_${Sample}_MT.shift.fasta 
    fi
done
${bwa} index $FINALPath/FINAL_${Sample}_MT.shift.fasta
ShiftRef="$FINALPath/FINAL_${Sample}_MT.shift.fasta"

###3. MAPPING TO MODIFIED REF (NORM AND SHIFTED)

#Mapping original WGS bams with bwa standard parameters, bam2fastq and interleave them
${bwa} mem -t 4 $ModRef $fastq1 $fastq2 | ${samtools} view -Shb -q 50 -f 2 - | ${samtools} sort - -o Mappings/${Sample}.MappingToModRef.bam -T Mappings/${Sample}.MappingToModRef.tmp
${samtools} index Mappings/${Sample}.MappingToModRef.bam
${bam2fastq} -o Mappings/${Sample}.MappingToModRef#.fastq Mappings/${Sample}.MappingToModRef.bam
${mtArchitect}/interleave-fastq.py Mappings/${Sample}.MappingToModRef_1.fastq Mappings/${Sample}.MappingToModRef_2.fastq | perl ${mtArchitect}/trimming_fastq_dinn.pl 32 > Mappings/${Sample}.MappingToModRefQual.fastq

#Same to shifted ref
${bwa} mem -t 4 $ShiftRef $fastq1 $fastq2 | ${samtools} view -Shb -q 50 -f 2 - | ${samtools} sort - -o Mappings/${Sample}.MappingToShiftRef.bam -T Mappings/${Sample}.MappingToShiftRef.tmp 
${samtools} index Mappings/${Sample}.MappingToShiftRef.bam
${bam2fastq} -o Mappings/${Sample}.MappingToShiftRef#.fastq Mappings/${Sample}.MappingToShiftRef.bam
${mtArchitect}/interleave-fastq.py Mappings/${Sample}.MappingToShiftRef_1.fastq Mappings/${Sample}.MappingToShiftRef_2.fastq | perl ${mtArchitect}/trimming_fastq_dinn.pl 32 > Mappings/${Sample}.MappingToShiftRefQual.fastq


### 4.NUCLEAR MAPPING

#Mapping to nuclear genome with standard parameters
${bwa} mem -t 4 -p ${NuclearRef} Mappings/${Sample}.MappingToModRefQual.fastq | ${samtools} view -Shb -f 2 - | ${samtools} sort - -o Mappings/${Sample}.MappingNuclearMit.bam -T Mappings/${Sample}.MappingNuclearMit.tmp
${samtools} index Mappings/${Sample}.MappingNuclearMit.bam
#Extract those mapping against mitochondrial genome
${samtools} view -hb Mappings/${Sample}.MappingNuclearMit.bam ${chrM} > Mappings/${Sample}.NonNuclear.bam
${samtools} index Mappings/${Sample}.NonNuclear.bam
${bam2fastq} -o Mappings/${Sample}.NonNuclear#.fastq Mappings/${Sample}.NonNuclear.bam
${mtArchitect}/interleave-fastq.py Mappings/${Sample}.NonNuclear_1.fastq Mappings/${Sample}.NonNuclear_2.fastq | perl ${mtArchitect}/trimming_fastq_dinn.pl 32 > $FINALPath/${Sample}.Final.fastq

#Same for shifted ref
${bwa} mem -t 4 -p ${NuclearRef} Mappings/${Sample}.MappingToShiftRefQual.fastq | ${samtools} view -Shb -f 2 - | ${samtools} sort - -o Mappings/${Sample}.MappingNuclearMitShift.bam -T Mappings/${Sample}.MappingNuclearMitShift.tmp
${samtools} index Mappings/${Sample}.MappingNuclearMitShift.bam
#Extract those mapping against mitochondrial genome
${samtools} view -hb Mappings/${Sample}.MappingNuclearMitShift.bam ${chrM} > Mappings/${Sample}.NonNuclearShift.bam
${samtools} index Mappings/${Sample}.NonNuclearShift.bam
${bam2fastq} -o Mappings/${Sample}.NonNuclearShift#.fastq Mappings/${Sample}.NonNuclearShift.bam
${mtArchitect}/interleave-fastq.py Mappings/${Sample}.NonNuclearShift_1.fastq Mappings/${Sample}.NonNuclearShift_2.fastq | perl ${mtArchitect}/trimming_fastq_dinn.pl 32 > $FINALPath/${Sample}.Shift.Final.fastq


### 5.ASSEMBLY

PATH=$PATH:${hapsembler}
mkdir Assembly
mkdir Assembly/${Sample}
mkdir Assembly/${Sample}/norm
mkdir Assembly/${Sample}/norm/consensus

#Calculate percentage of file needed to get 150x
readLength=$(cat $FINALPath/${Sample}.Final.fastq | head -n 2 | tail -n 1 | tr -d "\n" | wc -c)
NreadsNorm=$(($(cat $FINALPath/${Sample}.Final.fastq | wc -l)/4))
lengthRefNorm=$(cat $FINALPath/FINAL_${Sample}_MT.fasta | tail -n+2 | tr -d "\n" | wc -c)
per1000Norm=$(((150*1000*$lengthRefNorm)/($readLength*$NreadsNorm)))



for i in $(seq 1 1 20)
do
        #Subsample fastq
        cat $FINALPath/${Sample}.Final.fastq | ${mtArchitect}/random_pe.pl ${per1000Norm} > Assembly/${Sample}/norm/${Sample}.Final.$i.fastq
        #Use hapsembler to create contigs
        ${hapsembler}/hapsemble -p illumina -f Assembly/${Sample}/norm/${Sample}.Final.$i.fastq -o Assembly/${Sample}/norm/${Sample}.Finalout.$i.fa -a yes -t 4 -d 33 -m 20 -g 16
        #Align contigs to modified ref using blast
        ${blast}/makeblastdb -dbtype 'nucl' -in Assembly/${Sample}/norm/${Sample}.Finalout.$i.fa
        ${blast}/blastn -query ${FINALPath}/FINAL_${Sample}_MT.fasta -db Assembly/${Sample}/norm/${Sample}.Finalout.$i.fa -num_alignments 5000 -gapopen 0 -dust no -soft_masking false -outfmt 6  > Assembly/${Sample}/norm/${Sample}.aln.table.$i.fa
        #Create the consensus of the contigs
        ${Rscript} ${mtArchitect}/contigs_consensus.R ${FINALPath}/FINAL_${Sample}_MT.fasta Assembly/${Sample}/norm/${Sample}.Finalout.$i.fa Assembly/${Sample}/norm/${Sample}.aln.table.$i.fa norm
done


#Create consensus from the 20 iterations
cat Assembly/${Sample}/norm/consensus/${Sample}*.fa > Assembly/${Sample}/norm/consensus/${Sample}.iterations.norm.fa
${Rscript} ${mtArchitect}/iterations_consensus.R Assembly/${Sample}/norm/consensus/${Sample}.iterations.norm.fa Assembly/${Sample}/norm/consensus/${Sample}.consensus.norm.fa

#Same for shifted seq
mkdir Assembly/${Sample}/shift
mkdir Assembly/${Sample}/shift/consensus


NreadsShift=$(($(cat $FINALPath/${Sample}.Shift.Final.fastq | wc -l)/4))
lengthRefShift=$(cat ${ShiftRef} | tail -n+2 | tr -d "\n" | wc -c)
per1000Shift=$(((150*1000*$lengthRefShift)/($readLength*$NreadsShift)))


for i in $(seq 1 1 20)
do
        #Subsample fastq
        cat $FINALPath/${Sample}.Shift.Final.fastq | ${mtArchitect}/random_pe.pl ${per1000Shift} > Assembly/${Sample}/shift/${Sample}.Final.$i.fastq
        #Use hapsembler to create contigs
        ${hapsembler}/hapsemble -p illumina -f Assembly/${Sample}/shift/${Sample}.Final.$i.fastq -o Assembly/${Sample}/shift/${Sample}.Finalout.$i.fa -a yes -t 4 -d 33 -m 20 -g 16
        #Align contigs to modified ref using blast
        ${blast}/makeblastdb -dbtype 'nucl' -in Assembly/${Sample}/shift/${Sample}.Finalout.$i.fa
        ${blast}/blastn -query ${ShiftRef} -db Assembly/${Sample}/shift/${Sample}.Finalout.$i.fa -num_alignments 5000 -gapopen 0 -dust no -soft_masking false -outfmt 6 > Assembly/${Sample}/shift/${Sample}.aln.table.$i.fa
        #Create the consensus of the contigs
        ${Rscript} ${mtArchitect}/contigs_consensus.R ${ShiftRef} Assembly/${Sample}/shift/${Sample}.Finalout.$i.fa Assembly/${Sample}/shift/${Sample}.aln.table.$i.fa shift
done
#Create consensus from the 20 iterations
cat Assembly/${Sample}/shift/consensus/${Sample}*.fa > Assembly/${Sample}/shift/consensus/${Sample}.iterations.shift.fa
${Rscript} ${mtArchitect}/iterations_consensus.R Assembly/${Sample}/shift/consensus/${Sample}.iterations.shift.fa Assembly/${Sample}/shift/consensus/${Sample}.consensus.shift.fa


#Realign both sequences
mkdir FINALseq
mkdir FINALseq/${Sample}
cat Assembly/${Sample}/shift/consensus/${Sample}.consensus.shift.fa | tr - n > Assembly/${Sample}/shift/consensus/${Sample}.consensus.shift.c.fa
${bwa} index Assembly/${Sample}/norm/consensus/${Sample}.consensus.norm.fa
${bwa} mem Assembly/${Sample}/norm/consensus/${Sample}.consensus.norm.fa Assembly/${Sample}/shift/consensus/${Sample}.consensus.shift.c.fa | ${samtools} view -Sb - | ${samtools} sort - -o FINALseq/${Sample}/${Sample}.alignment.bam -T FINALseq/${Sample}/${Sample}.alignment.tmp
position=$(${samtools} view FINALseq/${Sample}/${Sample}.alignment.bam | awk '{if ($4==1) {split ($6,a,"H"); print a[1]+1}}')
prevpos=$((position-1))
ShiftLength=$(cat Assembly/${Sample}/shift/consensus/${Sample}.consensus.shift.fa | tail -n+2 | tr -d '\n' | wc -c | awk '{print $1}')
cat Assembly/${Sample}/shift/consensus/${Sample}.consensus.shift.fa | tail -n+2 | tr -d '\n' | cut -c ${position}-${ShiftLength} > FINALseq/${Sample}/${Sample}.tmp.fa
cat Assembly/${Sample}/shift/consensus/${Sample}.consensus.shift.fa | tail -n+2 | tr -d '\n' | cut -c 1-${prevpos} >> FINALseq/${Sample}/${Sample}.tmp.fa
printf ">Realigned_shifted\n" > FINALseq/${Sample}/${Sample}.realign.fa
printf ">Realigned_shifted\n" > FINALseq/${Sample}/${Sample}.realign.fa
if [ "$system" == "Darwin" ]; then
        cat FINALseq/${Sample}/${Sample}.tmp.fa | tr -d '\n' | sed -e 's/.\{60\}/&\'$'\n/g' >> FINALseq/${Sample}/${Sample}.realign.fa
else
        cat FINALseq/${Sample}/${Sample}.tmp.fa | tr -d '\n' | sed -e 's/.\{60\}/&\n/g' >> FINALseq/${Sample}/${Sample}.realign.fa
fi
cat Assembly/${Sample}/norm/consensus/${Sample}.consensus.norm.fa FINALseq/${Sample}/${Sample}.realign.fa > FINALseq/${Sample}/NormShift.fa

${Rscript} ${mtArchitect}/NormShiftCons.R FINALseq/${Sample}/NormShift.fa FINALseq/${Sample}/Final.tmp.${Sample}.fa
mkdir FINALseq/${Sample}/tmp
mv FINALseq/${Sample}/*.* FINALseq/${Sample}/tmp
cat FINALseq/${Sample}/tmp/Final.tmp.${Sample}.fa | tr [a-z] [A-Z] > FINALseq/${Sample}/${Sample}.fa
rm -f formatdb.log

#Mapping of last fq files to final reconstructed sequence (use it to inspect result with IGV)
${bwa} index FINALseq/${Sample}/${Sample}.fa
${bwa} mem FINALseq/${Sample}/${Sample}.fa Mappings/${Sample}.NonNuclearShift_1.fastq Mappings/${Sample}.NonNuclearShift_2.fastq | samtools view -Shb -f 2 - | samtools sort - -o FINALseq/${Sample}/${Sample}.bam -T FINALseq/${Sample}/${Sample}.tmp
${samtools} index ${Sample}.bam


#rm unnecessary files
rm -r Mappings/${Sample}* 


